summaryrefslogtreecommitdiffstats
path: root/karbon/render
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
commit7c71ab86d1f7e387fc3df63b48df07231f111862 (patch)
tree30ba2d2f840ff5fd458b6113e9c3f2e8a71d510d /karbon/render
parentafbfdc507bfaafc8824a9808311d57a9ece87510 (diff)
downloadkoffice-7c71ab86d1f7e387fc3df63b48df07231f111862.tar.gz
koffice-7c71ab86d1f7e387fc3df63b48df07231f111862.zip
Remove the tq in front of these incorrectly TQt4-converted methods/data members:
tqrepaint[...] tqinvalidate[...] tqparent[...] tqmask[...] tqlayout[...] tqalignment[...] git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1240522 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'karbon/render')
-rw-r--r--karbon/render/xrgbrender/gdk-pixbuf-xlib-render.c16
-rw-r--r--karbon/render/xrgbrender/gdk-pixbuf-xlib.h2
-rw-r--r--karbon/render/xrgbrender/gdk-pixbuf-xlibrgb.c2
3 files changed, 10 insertions, 10 deletions
diff --git a/karbon/render/xrgbrender/gdk-pixbuf-xlib.h b/karbon/render/xrgbrender/gdk-pixbuf-xlib.h
index 26d2426a..63961ea7 100644
--- a/karbon/render/xrgbrender/gdk-pixbuf-xlib.h
+++ b/karbon/render/xrgbrender/gdk-pixbuf-xlib.h
@@ -65,7 +65,7 @@ void gdk_pixbuf_xlib_render_to_drawable_alpha (GdkPixbuf *pixbuf,
void gdk_pixbuf_xlib_render_pixmap_and_tqmask (GdkPixbuf *pixbuf,
Pixmap *pixmap_return,
- Pixmap *tqmask_return,
+ Pixmap *mask_return,
int alpha_threshold);
diff --git a/karbon/render/xrgbrender/gdk-pixbuf-xlibrgb.c b/karbon/render/xrgbrender/gdk-pixbuf-xlibrgb.c
index 5c6c6ae0..171db33d 100644
--- a/karbon/render/xrgbrender/gdk-pixbuf-xlibrgb.c
+++ b/karbon/render/xrgbrender/gdk-pixbuf-xlibrgb.c
@@ -930,7 +930,7 @@ xlib_rgb_init_with_depth (Display *display, Screen *screen, int prefDepth)
static_image[i]->byte_order = MSBFirst;
}
}
- /* ok, so aptqparently, image_info->bpp is actually
+ /* ok, so apparently, image_info->bpp is actually
BYTES per pixel. What fun! */
switch (static_image[0]->bits_per_pixel) {
case 1:
diff --git a/karbon/render/xrgbrender/gdk-pixbuf-xlib-render.c b/karbon/render/xrgbrender/gdk-pixbuf-xlib-render.c
index f8f890e3..be1a839c 100644
--- a/karbon/render/xrgbrender/gdk-pixbuf-xlib-render.c
+++ b/karbon/render/xrgbrender/gdk-pixbuf-xlib-render.c
@@ -320,23 +320,23 @@ gdk_pixbuf_xlib_render_to_drawable_alpha (GdkPixbuf *pixbuf, Drawable drawable,
* @pixbuf: A pixbuf.
* @pixmap_return: Return value for the created pixmap.
* @tqmask_return: Return value for the created tqmask.
* @alpha_threshold: Threshold value for opacity values.
*
* Creates a pixmap and a tqmask bitmap which are returned in the @pixmap_return
* and @tqmask_return arguments, respectively, and renders a pixbuf and its
* corresponding tresholded alpha tqmask to them. This is merely a convenience
* function; applications that need to render pixbufs with dither offsets or to
* given drawables should use gdk_pixbuf_xlib_render_to_drawable_alpha() or
* gdk_pixbuf_xlib_render_to_drawable(), and
* gdk_pixbuf_xlib_render_threshold_alpha().
*
* If the pixbuf does not have an alpha channel, then *@tqmask_return will be set
* to None.
void
gdk_pixbuf_xlib_render_pixmap_and_tqmask (GdkPixbuf *pixbuf,
Pixmap *pixmap_return,
- Pixmap *tqmask_return,
+ Pixmap *mask_return,
int alpha_threshold)
{
g_return_if_fail (pixbuf != NULL);
@@ -361,20 +361,20 @@ gdk_pixbuf_xlib_render_pixmap_and_tqmask (GdkPixbuf *pixbuf,
XFreeGC (gdk_pixbuf_dpy, gc);
}
- if (tqmask_return) {
+ if (mask_return) {
if (pixbuf->has_alpha) {
- *tqmask_return = XCreatePixmap (gdk_pixbuf_dpy,
+ *mask_return = XCreatePixmap (gdk_pixbuf_dpy,
RootWindow (gdk_pixbuf_dpy,
gdk_pixbuf_screen),
pixbuf->width,
pixbuf->height, 1);
gdk_pixbuf_xlib_render_threshold_alpha (pixbuf,
- *tqmask_return,
+ *mask_return,
0, 0, 0, 0,
pixbuf->width,
pixbuf->height,
alpha_threshold);
} else
- *tqmask_return = 0;
+ *mask_return = 0;
}
}*/
@@ -320,23 +320,23 @@ gdk_pixbuf_xlib_render_to_drawable_alpha (GdkPixbuf *pixbuf, Drawable drawable,
* @pixbuf: A pixbuf.
* @pixmap_return: Return value for the created pixmap.
- * @tqmask_return: Return value for the created tqmask.
+ * @mask_return: Return value for the created tqmask.
* @alpha_threshold: Threshold value for opacity values.
*
@@ -320,23 +320,23 @@ gdk_pixbuf_xlib_render_to_drawable_alpha (GdkPixbuf *pixbuf, Drawable drawable,
*
* Creates a pixmap and a tqmask bitmap which are returned in the @pixmap_return
- * and @tqmask_return arguments, respectively, and renders a pixbuf and its
+ * and @mask_return arguments, respectively, and renders a pixbuf and its
* corresponding tresholded alpha tqmask to them. This is merely a convenience
* function; applications that need to render pixbufs with dither offsets or to
@@ -320,23 +320,23 @@ gdk_pixbuf_xlib_render_to_drawable_alpha (GdkPixbuf *pixbuf, Drawable drawable,
* gdk_pixbuf_xlib_render_threshold_alpha().
*
- * If the pixbuf does not have an alpha channel, then *@tqmask_return will be set
+ * If the pixbuf does not have an alpha channel, then *@mask_return will be set
* to None.
void